@@ -28,7 +28,6 @@
 #include "busy.h"
 #include "hierpack.h"
 
-
 /* 
  * select appropriate entry points based on if aet2
  * support is available
@@ -195,7 +194,9 @@ static unsigned long ae2_read_symbol_rows_2(AE2_HANDLE handle, unsigned long sym
 {
 if(symbol_idx <= GLOBALS->ae2_num_facs)
 	{
-	return(ae2_read_symbol_rows(handle, symbol_idx));
+	unsigned long r = ae2_read_symbol_rows(handle, symbol_idx);
+	if(r > AE2_MAX_ROWS) r = AE2_MAX_ROWS;
+	return(r);
 	}
 	else
 	{
@@ -232,13 +233,20 @@ if(numTerms)
 			fr2.length = -(length = at->first - at->last + 1);
 			}
 
-		ae2_read_value(handle, &fr2, cycle, value+offs);
+		if(fr2.s)
+			{
+			ae2_read_value(handle, &fr2, cycle, value+offs);
+			}
+			else
+			{
+			memset(value+offs, 'Z', fr2.length); /* should never happen except when alias is superset of available model facs */
+			}
 		offs += length;
 		}
 	}
 	else
 	{
-	/* should never happen */
+	/* should never happen except when alias is superset of available model facs */
 	memset(value, 'Z', tot_length);
 	}
 
@@ -277,7 +285,16 @@ if(numTerms)
 			fr2.length = -(length = at->first - at->last + 1);
 			}
 		
-		t_cyc = ae2_read_next_value(handle, &fr2, cycle, value+offs); /* simply want to calculate next value change time */
+		if(fr2.s)
+			{
+			t_cyc = ae2_read_next_value(handle, &fr2, cycle, value+offs); /* simply want to calculate next value change time */
+			}
+			else
+			{
+			/* should never happen except when alias is superset of available model facs */
+			t_cyc = cycle;
+			}
+
 		if(t_cyc != cycle)
 			{
 			if(t_cyc < cyc) { cyc = t_cyc; }
@@ -296,9 +313,10 @@ if(numTerms)
 	}
 	else
 	{
-	/* should never happen */
+	/* should never happen except when alias is superset of available model facs */
 	memset(value, 'Z', tot_length);
 	value[tot_length] = 0;
+	cyc = cycle;
 	}
 
 return(cyc);
@@ -416,9 +434,11 @@ struct Node *monolithic_node = NULL;
 struct symbol *monolithic_sym = NULL;
 #ifdef AET2_ALIASDB_IS_PRESENT
 unsigned long kw = 0;
+unsigned char *missing = NULL;
 #endif
 char buf[AE2_MAX_NAME_LENGTH+1];
 
+ae2_read_set_max_section_cycle(65536);
 ae2_initialize(error_fn, msg_fn, alloc_fn, free_fn);
 
 if ( (!(GLOBALS->ae2_f=fopen(fname, "rb"))) || (!(GLOBALS->ae2 = ae2_read_initialize(GLOBALS->ae2_f))) )
@@ -504,11 +524,14 @@ for(i=0;i<GLOBALS->ae2_num_facs;i++)
 	}
 
 #ifdef AET2_ALIASDB_IS_PRESENT
+missing = calloc_2(1, (GLOBALS->ae2_num_aliases + 7 + 1) / 8); /* + 1 to mirror idx value */
 for(i=0;i<GLOBALS->ae2_num_aliases;i++)
 	{
 	unsigned long numTerms;
         int idx = i+1;
 	int ii;
+	int midx, mbit;
+	int mcnt;
 
 	total_rows++;
 
@@ -536,19 +559,55 @@ for(i=0;i<GLOBALS->ae2_num_aliases;i++)
 		GLOBALS->adb_num_terms[i] = numTerms;
 		GLOBALS->adb_aliases[i] = adb_alloc_2(numTerms * sizeof(ADB_TERM));
 
+		mcnt = 0;
 		for(ii=0;ii<(numTerms);ii++)
 			{
 			GLOBALS->adb_aliases[i][ii].id = GLOBALS->adb_terms[ii+1].id;
+			if(!GLOBALS->adb_aliases[i][ii].id)
+				{
+				mcnt++;
+				}
 			GLOBALS->adb_aliases[i][ii].first = GLOBALS->adb_terms[ii+1].first;
 			GLOBALS->adb_aliases[i][ii].last = GLOBALS->adb_terms[ii+1].last;
         		}
+
+		if(mcnt)
+			{
+			midx = idx / 8;
+			mbit = idx & 7;
+			missing[midx] |= (1 << mbit);
+			}
 		}
 		else
 		{
-		memcpy(&GLOBALS->ae2_fr[match_idx], &GLOBALS->ae2_fr[GLOBALS->adb_terms[0].id-1], sizeof(AE2_FACREF));
+		unsigned long id = GLOBALS->adb_terms[0].id;
 
-		GLOBALS->adb_idx_first[i] = 0;
-		GLOBALS->adb_idx_last[i] = GLOBALS->ae2_fr[match_idx].length - 1;
+		if(id)
+			{
+			memcpy(&GLOBALS->ae2_fr[match_idx], &GLOBALS->ae2_fr[id-1], sizeof(AE2_FACREF));
+
+			GLOBALS->adb_idx_first[i] = 0;
+			GLOBALS->adb_idx_last[i] = GLOBALS->ae2_fr[match_idx].length - 1;
+			}
+			else /* not in model */
+			{
+			midx = idx / 8;
+			mbit = idx & 7;
+			missing[midx] |= (1 << mbit);
+
+			GLOBALS->ae2_fr[match_idx].length = 1;
+			GLOBALS->adb_idx_first[i] = 0;
+			GLOBALS->adb_idx_last[i] = 0;
+
+		        GLOBALS->ae2_fr[match_idx].s = idx + GLOBALS->ae2_num_facs; /* bias aliases after regular facs */
+
+			GLOBALS->ae2_fr[match_idx].facname = NULL;
+			GLOBALS->ae2_fr[match_idx].row = 0;
+		        GLOBALS->ae2_fr[match_idx].row_high = 0;
+		        GLOBALS->ae2_fr[match_idx].offset = 0;
+
+			GLOBALS->adb_num_terms[i] = 0;
+			}
 		}
 
 	match_idx++;
@@ -577,6 +636,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
         {
 	char *str;	
         int idx;
+	int typ;
 	unsigned long len, clen;
 	int row_iter, mx_row, mx_row_adjusted;
 
@@ -586,11 +646,13 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		idx = i+1;
 		len = ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
+		typ = (GLOBALS->ae2_fr[match_idx].row <= 1) ? ND_GEN_NET : ND_VCD_ARRAY;
 		}
 #ifdef AET2_ALIASDB_IS_PRESENT
 		else
 		{
 		idx = i - GLOBALS->ae2_num_facs + 1;
+		typ = (missing[idx/8] & (1 << (idx & 7))) ? ND_GEN_MISSING : ND_GEN_ALIAS;
 		len = adb_alias_name(GLOBALS->adb, idx, buf) - 1; /* it counts the null character */
 		}
 #endif
@@ -672,6 +734,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	for(row_iter = 0; row_iter < mx_row; row_iter++)
 		{
+		n[row_iter].vartype = typ;
 	        n[row_iter].nname=s->name;
 	        n[row_iter].mv.mvlfac = (struct fac *)(GLOBALS->ae2_fr+match_idx); /* to keep from having to allocate duplicate mvlfac struct */
 							               /* use the info in the AE2_FACREF array instead                */
@@ -707,6 +770,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 #ifdef AET2_ALIASDB_IS_PRESENT
 if(GLOBALS->adb_idx_last) { free_2(GLOBALS->adb_idx_last); GLOBALS->adb_idx_last = NULL; }
 if(GLOBALS->adb_idx_first) { free_2(GLOBALS->adb_idx_first); GLOBALS->adb_idx_first = NULL; }
+if(missing) { free_2(missing); missing = NULL; }
 #endif
 
 freeze_facility_pack();
@@ -966,7 +1030,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 	if((ecyc<cyc)||(ecyc==~ULLDescriptor(0))) continue;
 
 	autosort = calloc_2(ecyc - cyc + 1, sizeof(struct ae2_ncycle_autosort *));
-	
+
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		if(aet2_rd_get_fac_process_mask(i))
