@@ -242,10 +242,14 @@ WV_MENU_MLKRT,
 WV_MENU_MLKOFF,
 WV_MENU_VSG,
 WV_MENU_SEP9,
+WV_MENU_SHW,
+WV_MENU_SEP9B,
 WV_MENU_VSMO,
 WV_MENU_SEP9A,
 WV_MENU_VSBS,
 WV_MENU_SEP10,
+WV_MENU_ESTS,
+WV_MENU_SEP10A,
 WV_MENU_VDR,
 WV_MENU_SEP11,
 WV_MENU_VCZ,
