@@ -1681,6 +1681,7 @@ else if (*w2 == '[')
 	else
 	{
 	int rc = maketraces(w, alias, 0);
+
 	if(rc)
 		{
 		return(rc);
@@ -1695,6 +1696,13 @@ else if (*w2 == '[')
 			free_2(newl);
 			}
 
+		/* prevent malformed group openings [missing group opening] from keeping other signals from displaying */
+		if((!rc)&&(GLOBALS->default_flags&TR_GRP_BEGIN))
+			{
+			AddBlankTrace(w);
+			rc = ~0;
+			}
+
 		return(rc);
 		}
 	}
